@@ -53,16 +53,6 @@ func RouterCASecretName(operatorNamespace string) types.NamespacedName {
 	}
 }
 
-// RouterCAConfigMapName returns the namespaced name for the router CA configmap.
-// The operator uses this configmap to publish the public key for the CA
-// certificate, so that other operators can include it into their trust bundles.
-func RouterCAConfigMapName() types.NamespacedName {
-	return types.NamespacedName{
-		Namespace: GlobalMachineSpecifiedConfigNamespace,
-		Name:      "router-ca",
-	}
-}
-
 // DefaultIngressCertConfigMapName returns the namespaced name for the default ingress cert configmap.
 // The operator uses this configmap to publish the public key that golang clients can use to trust
 // the default ingress wildcard serving cert.
@@ -93,6 +83,14 @@ func RouterOperatorGeneratedDefaultCertificateSecretName(ci *operatorv1.IngressC
 	}
 }
 
+// RsyslogConfigMapName returns the namespaced name for the rsyslog configmap.
+func RsyslogConfigMapName(ic *operatorv1.IngressController) types.NamespacedName {
+	return types.NamespacedName{
+		Namespace: "openshift-ingress",
+		Name:      "rsyslog-conf-" + ic.Name,
+	}
+}
+
 // RouterPodDisruptionBudgetName returns the namespaced name for the router
 // deployment's pod disruption budget.
 func RouterPodDisruptionBudgetName(ic *operatorv1.IngressController) types.NamespacedName {
@@ -102,14 +100,6 @@ func RouterPodDisruptionBudgetName(ic *operatorv1.IngressController) types.Names
 	}
 }
 
-// RsyslogConfigMapName returns the namespaced name for the rsyslog configmap.
-func RsyslogConfigMapName(ic *operatorv1.IngressController) types.NamespacedName {
-	return types.NamespacedName{
-		Namespace: "openshift-ingress",
-		Name:      "rsyslog-conf-" + ic.Name,
-	}
-}
-
 // RouterEffectiveDefaultCertificateSecretName returns the namespaced name for
 // the in-use router default certificate secret.
 func RouterEffectiveDefaultCertificateSecretName(ci *operatorv1.IngressController, namespace string) types.NamespacedName {
@@ -119,6 +109,15 @@ func RouterEffectiveDefaultCertificateSecretName(ci *operatorv1.IngressControlle
 	return RouterOperatorGeneratedDefaultCertificateSecretName(ci, namespace)
 }
 
+// ServiceCAConfigMapName returns the namespaced name for the
+// configmap with the service CA bundle.
+func ServiceCAConfigMapName() types.NamespacedName {
+	return types.NamespacedName{
+		Namespace: "openshift-ingress",
+		Name:      "service-ca-bundle",
+	}
+}
+
 func IngressControllerDeploymentLabel(ic *operatorv1.IngressController) string {
 	return ic.Name
 }
